==> eiffelstudio-19.05.10.3187.tar: F_code/C1/st17.c <==
/*
 * Code for class STD_FILES
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "st17.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {STD_FILES}.input */
static EIF_REFERENCE F36_394_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	

	RTLI(2);
	RTLR(0,tr1);
	RTLR(1,tr2);
	RTLIU(2);
	
	RTEV;
	RTGC;
	RTOSP (394);
#define Result RTOSR(394)
	RTOC_NEW(Result);
	tr1 = RTLNS(eif_new_type(900, 0x01).id, 900, _OBJSIZ_3_7_2_4_1_1_2_1_);
	tr2 = RTMS_EX_H("stdin",5,1953620846);
	F901_5731(RTCW(tr1), tr2);
	Result = (EIF_REFERENCE) tr1;
	RTOSE (394);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F36_394 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(394,F36_394_body,(Current));
}

/* {STD_FILES}.output */
static EIF_REFERENCE F36_395_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	

	RTLI(2);
	RTLR(0,tr1);
	RTLR(1,tr2);
	RTLIU(2);
	
	RTEV;
	RTGC;
	RTOSP (395);
#define Result RTOSR(395)
	RTOC_NEW(Result);
	tr1 = RTLNS(eif_new_type(900, 0x01).id, 900, _OBJSIZ_3_7_2_4_1_1_2_1_);
	tr2 = RTMS_EX_H("stdout",6,1912016244);
	F901_5732(RTCW(tr1), tr2);
	Result = (EIF_REFERENCE) tr1;
	RTOSE (395);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F36_395 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(395,F36_395_body,(Current));
}

/* {STD_FILES}.error */
static EIF_REFERENCE F36_396_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	

	RTLI(2);
	RTLR(0,tr1);
	RTLR(1,tr2);
	RTLIU(2);
	
	RTEV;
	RTGC;
	RTOSP (396);
#define Result RTOSR(396)
	RTOC_NEW(Result);
	tr1 = RTLNS(eif_new_type(900, 0x01).id, 900, _OBJSIZ_3_7_2_4_1_1_2_1_);
	tr2 = RTMS_EX_H("stderr",6,1911360114);
	F901_5733(RTCW(tr1), tr2);
	Result = (EIF_REFERENCE) tr1;
	RTOSE (396);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F36_396 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(396,F36_396_body,(Current));
}

/* {STD_FILES}.set_output_default */
void F36_420 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	tr1 = RTOSCF(395,F36_395, (Current));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	RTLE;
}

void EIF_Minit17 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-23.09.10.7341.tar: F_code/C1/st17.c <==
/*
 * Code for class STD_FILES
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "st17.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {STD_FILES}.output */
static EIF_REFERENCE F30_435_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	
#define Result RTOTRR
	RTOUDR(33)

	RTLI(2);
	RTLR(0,tr1);
	RTLR(1,tr2);
	RTLIU(2);
	
	RTEV;
	RTGC;
	RTOTP;
	tr1 = RTLNS(eif_new_type(899, 0x01).id, 899, _OBJSIZ_5_7_2_4_1_1_2_1_);
	tr2 = RTMS_EX_H("stdout",6,1912016244);
	F900_5684(RTCW(tr1), tr2);
	Result = (EIF_REFERENCE) tr1;
	RTOTE;
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F30_435 (EIF_REFERENCE Current)
{
	GTCX
	return RTOUCR(33,F30_435_body,(Current));
}

/* {STD_FILES}.error */
static EIF_REFERENCE F30_436_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	
#define Result RTOTRR
	RTOUDR(34)

	RTLI(2);
	RTLR(0,tr1);
	RTLR(1,tr2);
	RTLIU(2);
	
	RTEV;
	RTGC;
	RTOTP;
	tr1 = RTLNS(eif_new_type(899, 0x01).id, 899, _OBJSIZ_5_7_2_4_1_1_2_1_);
	tr2 = RTMS_EX_H("stderr",6,1911360114);
	F900_5685(RTCW(tr1), tr2);
	Result = (EIF_REFERENCE) tr1;
	RTOTE;
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F30_436 (EIF_REFERENCE Current)
{
	GTCX
	return RTOUCR(34,F30_436_body,(Current));
}

/* {STD_FILES}.set_output_default */
void F30_462 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	tr1 = RTOUCR(33,F30_435, (Current));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	RTLE;
}

void EIF_Minit17 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
